Learn R Programming

narfima (version 0.1.0)

auto_nnaive: Fitting a NNaive Model

Description

This function fits Neural Naive (NNaive) model to a univariate time series. It follows the same framework as narfima, but replaces the ARFIMA component with a Naive model. This function is intended for ablation studies to benchmark the performance of narfima against alternatives.

Usage

auto_nnaive(
  y,
  er,
  xreg = NULL,
  p,
  q,
  P = 1,
  size,
  skip,
  repeats = 1000,
  lambda = 0.5,
  lambdae = 0.5,
  scale.inputs = TRUE,
  ...
)

Value

Returns an object of class "narfima" with the same structure as narfima, but using Naive residuals instead of ARFIMA residuals.

Arguments

y

A numeric vector or time series of class ts.

er

A numeric vector or time series object representing the series of residuals. If missing, it will be calculated from a Naive model.

xreg

An optional numeric matrix of exogenous variables to be included in the model (default is NULL).

p

Integer indicating the number of lags of the input series y.

q

Integer indicating the number of lags of the errors er.

P

Integer indicating the number of seasonal lags of the input series y (default is 1).

size

Integer specifying the number of nodes of the feed-forward neural networks with a single hidden layer.

skip

Logical value indicating whether to use the direct connections in the neural network (default is TRUE).

repeats

Integer specifying the number of times to fit the neural network model (default is 1000).

lambda

Numeric value for the Box-Cox transformation parameter of y (default is 0.5).

lambdae

Numeric value for the Box-Cox transformation parameter of er (default is 0.5).

scale.inputs

Logical value indicating whether to standardize the inputs before fitting the model (default is TRUE).

...

Additional arguments passed to auto_nnaive.